@@ -42,7 +42,11 @@ class DateTimeClock(clock.Clock):
             text = text + y
         
         self.context.text_path(text)
-        self.context.stroke()
+
+        if self.fill :
+            self.context.fill()
+        else :
+          self.context.stroke()
 
 # Draw time.
         self.context.move_to(2, 35)
@@ -61,7 +65,11 @@ class DateTimeClock(clock.Clock):
             text = text + ":" + str(self.time.second).zfill(2)
         
         self.context.text_path(text)
-        self.context.stroke()
+
+        if self.fill :
+            self.context.fill()
+        else :
+          self.context.stroke()
 
         if self.twelve_hour_mode :
             self.context.set_font_size(10)
@@ -72,7 +80,11 @@ class DateTimeClock(clock.Clock):
                 self.context.move_to(65, 35)
             
             self.context.text_path(abrv)
-            self.context.stroke()
+
+            if self.fill :
+                self.context.fill()
+            else :
+                self.context.stroke()
 
     def resize(self):
         if self.twelve_hour_mode :
